@@ -1,6 +1,6 @@
-import subprocess, torch
-from fastai.basics import *
-from fastscript import *
+import subprocess,torch,os,sys
+from fastcore.basics import *
+from fastcore.script import *
 
 @call_parse
 def main(
@@ -9,18 +9,15 @@ def main(
     args:Param("Args to pass to script", nargs='...', opt=False)=''
 ):
     "PyTorch distributed training launch helper that spawns multiple distributed processes"
-    # Loosely based on torch.distributed.launch
     current_env = os.environ.copy()
-    gpus = list(range(torch.cuda.device_count())) if gpus=='all' else list(gpus)
+    gpus = list(range(torch.cuda.device_count())) if gpus=='all' else gpus.split(',')
     current_env["WORLD_SIZE"] = str(len(gpus))
     current_env["MASTER_ADDR"] = '127.0.0.1'
     current_env["MASTER_PORT"] = '29500'
 
-    processes = []
+    procs = []
     for i,gpu in enumerate(gpus):
-        current_env["RANK"] = str(i)
-        cmd = [sys.executable, "-u", script, f"--gpu={gpu}"] + args
-        process = subprocess.Popen(cmd, env=current_env)
-        processes.append(process)
+        current_env["RANK"],current_env["DEFAULT_GPU"] = str(i),str(gpu)
+        procs.append(subprocess.Popen([sys.executable, "-u", script] + args, env=current_env))
+    for p in procs: p.wait()
 
-    for process in processes: process.wait()
